PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Namespaces | Functions
DSN.hpp File Reference
`#include <map>`
`#include <set>`
`#include <string>`
`#include <vector>`

Go to the source code of this file.

## Data Structures
struct | dsn::BBox
struct | dsn::PCB
struct | dsn::Layer
struct | dsn::Segment
struct | dsn::Via
struct | dsn::Track
struct | dsn::Connection
struct | dsn::Net
struct | dsn::Path
struct | dsn::Shape
struct | dsn::Padstack
struct | dsn::Pin
struct | dsn::Image
struct | dsn::Structure
struct | dsn::Placement
struct | dsn::Data

## Namespaces
namespace | dsn

## Functions
BBox | dsn::get_bounding_box (const std::vector< double > &xy, double expansion)